@@ -76,7 +76,6 @@ sub _resolveSubmenue($){
     return  if( ref \$opt->{'jump'} ne 'SCALAR' );
 
     my $subName = $opt->{'jump'};
-    #return  if( !defined $self->{'def'}{$subName} );
     $opt->{'jump'} = \&Script::Toolbox::Util::Menues::run;
     $opt->{'argv'} = [$self,$subName];
     return;
@@ -205,6 +204,7 @@ sub addOption($$){
 
     $self->{'def'}{$name}{'opts'} = []  if( ! defined $self->{'def'}{$name}{'opts'} );
 
+    $self->_resolveSubmenue($opt);
     push @{$self->{'def'}{$name}{'opts'}}, $opt;
     return;
 }
